summaryrefslogtreecommitdiffstats
path: root/libkdepim/qutf7codec.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/qutf7codec.h')
-rw-r--r--libkdepim/qutf7codec.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/libkdepim/qutf7codec.h b/libkdepim/qutf7codec.h
index b3380b1f..675692af 100644
--- a/libkdepim/qutf7codec.h
+++ b/libkdepim/qutf7codec.h
@@ -1,7 +1,7 @@
/*
qutf7codec.h
- A QTextCodec for UTF-7 (rfc2152).
+ A TQTextCodec for UTF-7 (rfc2152).
Copyright (c) 2001 Marc Mutz <mutz@kde.org>
See file COPYING for details
@@ -26,41 +26,41 @@
#define QUTF7CODEC_H
#ifndef QT_H
-#include "qtextcodec.h"
+#include "tqtextcodec.h"
#endif
#include <kdepimmacros.h>
#ifndef QT_NO_TEXTCODEC
-/** @short A QTextCodec for the UTF-7 transformation of Unicode.
+/** @short A TQTextCodec for the UTF-7 transformation of Unicode.
- This is a QTextCodec for the UTF-7 transformation of Unicode,
+ This is a TQTextCodec for the UTF-7 transformation of Unicode,
described in RFC2152.
- Use it as you would use any other QTextCodec. Only if you use the
+ Use it as you would use any other TQTextCodec. Only if you use the
encoder directly (via makeEncoder), you should bear in mind
that if your application needs the encoder to return to ASCII mode
(like it's the case for RFC2047 mail header encoded words), you
have to tell the encoder by requesting the encoding of a @em null
- QString.
+ TQString.
@author Marc Mutz <mutz@kde.org> */
-class KDE_EXPORT QUtf7Codec : public QTextCodec {
+class KDE_EXPORT QUtf7Codec : public TQTextCodec {
bool encOpt, encLwsp;
public:
- QUtf7Codec() : QTextCodec() {}
+ QUtf7Codec() : TQTextCodec() {}
int mibEnum() const;
const char* name() const;
const char* mimeName() const;
- QTextDecoder* makeDecoder() const;
- QTextEncoder* makeEncoder() const;
+ TQTextDecoder* makeDecoder() const;
+ TQTextEncoder* makeEncoder() const;
- bool canEncode( QChar ) const;
- bool canEncode( const QString& ) const;
+ bool canEncode( TQChar ) const;
+ bool canEncode( const TQString& ) const;
int heuristicContentMatch( const char* chars, int len ) const;
};
@@ -90,7 +90,7 @@ public:
const char* name() const;
int mibEnum() const;
- QTextEncoder* makeEncoder() const;
+ TQTextEncoder* makeEncoder() const;
};
#endif // QT_NO_TEXTCODEC